aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--NorthstarDLL/squirrel.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/NorthstarDLL/squirrel.cpp b/NorthstarDLL/squirrel.cpp
index 06a88ba3..02ca651e 100644
--- a/NorthstarDLL/squirrel.cpp
+++ b/NorthstarDLL/squirrel.cpp
@@ -360,9 +360,9 @@ void __fastcall ScriptCompileErrorHook(HSquirrelVM* sqvm, const char* error, con
// kill dedicated server if we hit this
if (IsDedicatedServer())
{
// flush the logger before we abort so debug things get saved to log file
logger->flush();
- abort();
+ exit(EXIT_FAILURE);
}
else
{
@@ -360,9 +360,9 @@ void __fastcall ScriptCompileErrorHook(HSquirrelVM* sqvm, const char* error, con
if (IsDedicatedServer())
{
- // flush the logger before we abort so debug things get saved to log file
+ // flush the logger before we exit so debug things get saved to log file
logger->flush();